/****************************************************************************/
/*                                                                          */
/*                      Chaine de CAO & VLSI   Alliance                     */
/*                                                                          */
/*    Produit :  optimiseur de netlist                                      */
/*    Fichier :  no_system.h                                                */
/*                                                                          */
/*    (c) copyright 1991 Laboratoire MASI equipe CAO & VLSI                 */
/*    Tous droits reserves                                                  */
/*    Support : e-mail cao-vlsi@masi.ibp.fr                                 */
/*                                                                          */
/*    Auteur(s) :  N. Dictus                            le : 22/09/1993     */
/*                                                                          */
/*    Modifie par :                                     le : ../../....     */
/*    Modifie par :                                     le : ../../....     */
/*    Modifie par :                                     le : ../../....     */
/*                                                                          */
/****************************************************************************/

#ifdef LAX 
#include "../lax/LXU_text.h"
#include "../lax/LSS_info.h"
#define PRINTF LXU_PrintMSG
#define PRINTI LSS_PrintInfo
#else 
#define PRINTF printf
#define PRINTI printf
#endif

pTH assignTH;
long indexMaximum;

lofig_list *initializeNet();
void cellEnd();
int verifArgs();
param *initializeNOParam();
no_system *initializeNOSystem();
void majNOSystem();
void displaySystem();
void OPTIMISATION_LOCALE();
void OPTIMISATION_GLOBALE();
void INFORMATION();
lofig_list *laxAssignFanin();
lofig_list *laxOptimFanout();
